@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/mpmath.h,v 1.7 2005/02/07 16:38:58 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/mpmath.h,v 1.12 2006/09/13 17:41:46 sampie Exp $
  *
- *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,13 +42,14 @@ void calc_not(int t[MP_SIZE], int s1[MP_SIZE]);
 void calc_rand(int t[MP_SIZE]);
 void calc_u32(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_u16(int s1[MP_SIZE], int t1[MP_SIZE]);
-void calc_percent(int s1[MP_SIZE], int s2[MP_SIZE], int t1[MP_SIZE]);
+void calc_percent(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_inv(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_tenpowx(int s1[MP_SIZE], int t1[MP_SIZE]);
 void calc_xpowy(int MPx[MP_SIZE], int MPy[MP_SIZE], int MPres[MP_SIZE]);
 void do_zero(int t1[MP_SIZE]);
 void do_e(int t1[MP_SIZE]);
 void calc_xtimestenpowx(int s1[MP_SIZE], int s2[MP_SIZE], int t1[MP_SIZE]);
+int calc_modulus(int op1[MP_SIZE], int op2[MP_SIZE], int result[MP_SIZE]);
 void calc_ctrm(int t[MP_SIZE]);
 void calc_ddb(int t[MP_SIZE]);
 void calc_fv(int t[MP_SIZE]);
@@ -59,5 +60,16 @@ void calc_sln(int t[MP_SIZE]);
 void calc_syd(int t[MP_SIZE]);
 void calc_term(int t[MP_SIZE]);
 void calc_rshift(int s[MP_SIZE], int t[MP_SIZE], int times, enum shiftd dir);
+void calc_epowy(int s[MP_SIZE], int t[MP_SIZE]);
+
+/* return true if parameter is integer */
+int
+is_integer(int MPnum[MP_SIZE]);
+
+/* return true if parameter is natural
+   number, that is, a positive integer
+*/
+int
+is_natural(int MPnum[MP_SIZE]);
 
 #endif /*MPMATH_H*/
